@@ -21,7 +21,7 @@ class DatabaseInterface(object):
 
         :return: the database
         '''
-        raise
+        raise NotImplementedError
 
     def cursor(self, autocommit=False):
         '''
@@ -30,13 +30,13 @@ class DatabaseInterface(object):
         :param autocommit: a boolean to active autocommit
         :return: a Cursor
         '''
-        raise
+        raise NotImplementedError
 
     def close(self):
         '''
         Close all connection
         '''
-        raise
+        raise NotImplementedError
 
     def create(self, cursor, database_name):
         '''
@@ -44,7 +44,7 @@ class DatabaseInterface(object):
 
         :param database_name: the database name
         '''
-        raise
+        raise NotImplementedError
 
     def drop(self, cursor, database_name):
         '''
@@ -53,7 +53,7 @@ class DatabaseInterface(object):
         :param cursor: a cursor on an other database
         :param database_name: the database name
         '''
-        raise
+        raise NotImplementedError
 
     @staticmethod
     def dump(database_name):
@@ -63,7 +63,7 @@ class DatabaseInterface(object):
         :param database_name: the database name
         :return: the dump
         '''
-        raise
+        raise NotImplementedError
 
     @staticmethod
     def restore(database_name, data):
@@ -74,6 +74,7 @@ class DatabaseInterface(object):
         :param data: the data
         :return: True if succeed
         '''
+        raise NotImplementedError
 
     @staticmethod
     def list(cursor):
@@ -82,7 +83,7 @@ class DatabaseInterface(object):
 
         :return: a list of database name
         '''
-        raise
+        raise NotImplementedError
 
     @staticmethod
     def init(cursor):
@@ -91,7 +92,7 @@ class DatabaseInterface(object):
 
         :param cursor: a cursor on the database
         '''
-        raise
+        raise NotImplementedError
 
 
 class CursorInterface(object):
@@ -111,6 +112,8 @@ class CursorInterface(object):
         :param context: the context
         :return: the cache dictionary
         '''
+        from trytond.transaction import Transaction
+        user = Transaction().user
         if context is None:
             context = {}
         cache_ctx = context.copy()
@@ -118,7 +121,7 @@ class CursorInterface(object):
                 '_delete_records'):
             if i in cache_ctx:
                 del cache_ctx[i]
-        return self.cache.setdefault(repr(cache_ctx), {})
+        return self.cache.setdefault((user, repr(cache_ctx)), {})
 
     def execute(self, sql, params=None):
         '''
@@ -127,7 +130,7 @@ class CursorInterface(object):
         :param sql: a sql query string
         :param params: a tuple or list of parameters
         '''
-        raise
+        raise NotImplementedError
 
     def close(self, close=False):
         '''
@@ -135,7 +138,7 @@ class CursorInterface(object):
 
         :param close: boolean to not release cursor in pool
         '''
-        raise
+        raise NotImplementedError
 
     def commit(self):
         '''
@@ -153,7 +156,7 @@ class CursorInterface(object):
         '''
         Test if it is a Tryton database.
         '''
-        raise
+        raise NotImplementedError
 
     def nextid(self, table):
         '''
@@ -185,13 +188,13 @@ class CursorInterface(object):
         :return: an integer
         '''
 
-    def has_lock(self):
+    def lock(self, table):
         '''
-        Return True if database handle lock table.
+        Lock the table
 
-        :return: a boolean
+        :param table: the table name
         '''
-        raise
+        raise NotImplementedError
 
     def has_constraint(self):
         '''
@@ -199,7 +202,7 @@ class CursorInterface(object):
 
         :return: a boolean
         '''
-        raise
+        raise NotImplementedError
 
     def limit_clause(self, select, limit=None, offset=None):
         '''
@@ -210,4 +213,13 @@ class CursorInterface(object):
         :param offset: the offset
         :return: a string
         '''
-        raise
+        raise NotImplementedError
+
+    def update_auto_increment(self, table, value):
+        '''
+        Update auto_increment value of table
+
+        :param table: the table name
+        :param value: the auto_increment value
+        '''
+        pass
