@@ -1,6 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-
+from __future__ import with_statement
 from trytond.backend.database import DatabaseInterface, CursorInterface
 from trytond.config import CONFIG
 import MySQLdb
@@ -108,9 +108,8 @@ class Database(DatabaseInterface):
         cmd.append(database_name)
 
         fd, file_name = tempfile.mkstemp()
-        fd = os.fdopen(fd, 'wb+')
-        fd.write(data)
-        fd.close()
+        with os.fdopen(fd, 'wb+') as fd:
+            fd.write(data)
 
         cmd.append('<')
         cmd.append(file_name)
@@ -164,15 +163,17 @@ class Database(DatabaseInterface):
     def init(cursor):
         from trytond.tools import safe_eval
         sql_file = os.path.join(os.path.dirname(__file__), 'init.sql')
-        for line in open(sql_file).read().split(';'):
-            if (len(line)>0) and (not line.isspace()):
-                cursor.execute(line)
+        with open(sql_file) as fp:
+            for line in fp.read().split(';'):
+                if (len(line)>0) and (not line.isspace()):
+                    cursor.execute(line)
 
         for i in ('ir', 'workflow', 'res', 'webdav'):
             root_path = os.path.join(os.path.dirname(__file__), '..', '..')
             tryton_file = os.path.join(root_path, i, '__tryton__.py')
             mod_path = os.path.join(root_path, i)
-            info = safe_eval(open(tryton_file).read())
+            with open(tryton_file) as fp:
+                info = safe_eval(fp.read())
             active = info.get('active', False)
             if active:
                 state = 'to install'
@@ -299,7 +300,8 @@ class Cursor(CursorInterface):
     def lock(self, table):
         # Lock of table doesn't work because MySQL require
         # that the session locks all tables that will be accessed
-        self.cursor.execute('FLUSH TABLES WITH READ LOCK')
+        # but 'FLUSH TABLES WITH READ LOCK' creates deadlock
+        pass
 
     def has_constraint(self):
         return False
