@@ -11,11 +11,12 @@ def domain_validate(value):
             if isinstance(arg, basestring):
                 if arg not in ('AND', 'OR'):
                     return False
-            elif isinstance(arg, tuple) or \
-                    (isinstance(arg, list) and len(arg) > 2 and \
-                    (arg[1] in OPERATORS) or \
-                    (isinstance(arg[1], PYSON) and \
-                    arg[1].types() == set([str]))):
+            elif (isinstance(arg, tuple)
+                or (isinstance(arg, list)
+                    and len(arg) > 2
+                    and ((arg[1] in OPERATORS)
+                        or (isinstance(arg[1], PYSON)
+                            and arg[1].types() == set([str]))))):
                 pass
             elif isinstance(arg, list):
                 if not test_domain(arg):
@@ -53,9 +54,9 @@ class Field(object):
     _type = None
 
     def __init__(self, string='', help='', required=False, readonly=False,
-            domain=None, states=None, priority=0, change_default=False,
-            select=0, on_change=None, on_change_with=None,
-            depends=None, order_field=None, context=None):
+            domain=None, states=None, change_default=False, select=0,
+            on_change=None, on_change_with=None, depends=None,
+            order_field=None, context=None, loading='eager'):
         '''
         :param string: A string for label of the field.
         :param help: A multi-line help string.
@@ -67,7 +68,6 @@ class Field(object):
             ``readonly`` and ``invisible``. Values are pyson expressions that
             will be evaluated with record values. This allows to change
             dynamically the attributes of the field.
-        :param priority: Give the order in which setter methods are called.
         :param change_default: A boolean. If ``True`` the field can be used as
         condition for a custom default value.
         :param select: An integer. When equal to ``1``, the field appears in the
@@ -85,6 +85,8 @@ class Field(object):
             ordering records on the field.
         :param context: A dictionary which will be given to open the relation
             fields.
+        :param loading: Define how the field must be loaded:
+            ``lazy`` or ``eager``.
         '''
         assert string, 'a string is required'
         self.string = string
@@ -95,7 +97,6 @@ class Field(object):
         self.domain = domain or []
         self.__states = None
         self.states = states or {}
-        self.priority = priority
         self.change_default = change_default
         self.select = select
         self.__on_change = None
@@ -107,6 +108,8 @@ class Field(object):
         self.order_field = order_field
         self.__context = None
         self.context = context or {}
+        assert loading in ('lazy', 'eager'), 'loading must be "lazy" or "eager"'
+        self.loading = loading
 
     def _get_domain(self):
         return self.__domain
