@@ -21,6 +21,7 @@ from trytond.tools import safe_eval, reduce_domain
 from trytond.pyson import PYSONEncoder, PYSONDecoder, PYSON
 from trytond.const import OPERATORS
 from trytond.transaction import Transaction
+from trytond.config import CONFIG
 
 
 class ModelStorage(Model):
@@ -82,7 +83,11 @@ class ModelStorage(Model):
         :return: the id of the created record
         '''
         model_access_obj = self.pool.get('ir.model.access')
+        model_field_access_obj = self.pool.get('ir.model.field.access')
+
         model_access_obj.check(self._name, 'create')
+        model_field_access_obj.check(self._name,
+                [x for x in values if x in self._columns], 'write')
         self.__clean_xxx2many_cache()
         return False
 
@@ -113,8 +118,11 @@ class ModelStorage(Model):
             and fields value as value. The list will not be in the same order.
         '''
         model_access_obj = self.pool.get('ir.model.access')
+        model_field_access_obj = self.pool.get('ir.model.field.access')
 
         model_access_obj.check(self._name, 'read')
+        model_field_access_obj.check(self._name,
+                fields_names or self._columns.keys(), 'read')
         if isinstance(ids, (int, long)):
             return {}
         return []
@@ -129,8 +137,11 @@ class ModelStorage(Model):
         :return: True if succeed
         '''
         model_access_obj = self.pool.get('ir.model.access')
+        model_field_access_obj = self.pool.get('ir.model.field.access')
 
         model_access_obj.check(self._name, 'write')
+        model_field_access_obj.check(self._name,
+                [x for x in values if x in self._columns], 'write')
         if not self.check_xml_record(ids, values):
             self.raise_user_error('write_xml_record',
                     error_description='xml_record_desc')
@@ -278,7 +289,7 @@ class ModelStorage(Model):
                     data[field_name] = default[field_name]
                 elif ftype == 'function':
                     del data[field_name]
-                elif ftype == 'many2one':
+                elif ftype in ('many2one', 'one2one'):
                     try:
                         data[field_name] = data[field_name] and \
                                 data[field_name][0]
@@ -522,7 +533,13 @@ class ModelStorage(Model):
                     break
                 field_name = fields_tree[i]
                 model_obj = self.pool.get(value._model_name)
-                field = model_obj._columns[field_name]
+                if field_name in model_obj._columns:
+                    field = model_obj._columns[field_name]
+                elif field_name in model_obj._inherit_fields:
+                    field = model_obj._inherit_fields[field_name][2]
+                else:
+                    raise Exception('Field %s not available on object "%s"'
+                        % (field_name, model_obj._name))
                 if field.states and 'invisible' in field.states:
                     pyson_invisible = PYSONEncoder().encode(
                             field.states['invisible'])
@@ -649,6 +666,9 @@ class ModelStorage(Model):
                     res = [('set', res)]
                 return res
 
+            def get_one2one(relation, value):
+                return ('set', get_many2one(relation, value))
+
             def get_reference(value):
                 if not value:
                     return False
@@ -750,6 +770,8 @@ class ModelStorage(Model):
                         res = get_many2one(this_field_def['relation'], value)
                     elif field_type == 'many2many':
                         res = get_many2many(this_field_def['relation'], value)
+                    elif field_type == 'one2one':
+                        res = get_one2one(this_field_def['relation'], value)
                     elif field_type == 'reference':
                         res = get_reference(value)
                     else:
@@ -970,8 +992,9 @@ class ModelStorage(Model):
                         not field.setter:
                     continue
                 # validate domain
-                if field._type in ('many2one', 'many2many', 'one2many') \
-                        and field.domain:
+                if (field._type in
+                        ('many2one', 'many2many', 'one2many', 'one2one')
+                    and field.domain):
                     if field._type in ('many2one', 'one2many'):
                         relation_obj = self.pool.get(field.model_name)
                     else:
@@ -1064,6 +1087,17 @@ class ModelStorage(Model):
                                     'size_validation_record',
                                     error_args=self._get_error_args(field_name))
 
+                def digits_test(value, digits, field_name):
+                    def raise_user_error():
+                        self.raise_user_error('digits_validation_record',
+                            error_args=self._get_error_args(field_name))
+                    if isinstance(value, Decimal):
+                        if not (value.quantize(Decimal(str(10.0**-digits[1])))
+                                == value):
+                            raise_user_error()
+                    elif CONFIG.options['db_type'] != 'mysql':
+                        if not (round(value, digits[1]) == float(value)):
+                            raise_user_error()
                 # validate digits
                 if hasattr(field, 'digits') and field.digits:
                     if is_pyson(field.digits):
@@ -1076,27 +1110,18 @@ class ModelStorage(Model):
                             env['context'] = Transaction().context
                             env['active_id'] = record.id
                             digits = PYSONDecoder(env).decode(pyson_digits)
-                            if not round(record[field_name], digits[1]) == \
-                                    float(record[field_name]):
-                                self.raise_user_error(
-                                        'digits_validation_record',
-                                        error_args=self._get_error_args(
-                                            field_name))
+                            digits_test(record[field_name], digits, field_name)
                     else:
                         for record in records:
-                            if not round(record[field_name], field.digits[1]) == \
-                                    float(record[field_name]):
-                                self.raise_user_error(
-                                        'digits_validation_record',
-                                        error_args=self._get_error_args(
-                                            field_name))
+                            digits_test(record[field_name], field.digits,
+                                field_name)
 
     def _clean_defaults(self, defaults):
         vals = {}
         for field in defaults.keys():
             fld_def = (field in self._columns) and self._columns[field] \
                     or self._inherit_fields[field][2]
-            if fld_def._type in ('many2one',):
+            if fld_def._type in ('many2one', 'one2one'):
                 if isinstance(defaults[field], (list, tuple)):
                     vals[field] = defaults[field][0]
                 else:
