@@ -1,10 +1,10 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-"Request"
-from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Eval, In, If, Not, Equal
 import time
 import datetime
+from trytond.model import ModelView, ModelSQL, fields
+from trytond.pyson import Eval, In, If, Not, Equal
+from trytond.transaction import Transaction
 
 _STATES = [
     ('draft', 'Draft'),
@@ -62,16 +62,16 @@ class Request(ModelSQL, ModelView):
     history = fields.One2Many('res.request.history', 'request',
            'History', readonly=True)
 
-    def default_act_from(self, cursor, user, context=None):
-        return int(user)
+    def default_act_from(self):
+        return int(Transaction().user)
 
-    def default_state(self, cursor, user, context=None):
+    def default_state(self):
         return 'draft'
 
-    def default_active(self, cursor, user, context=None):
+    def default_active(self):
         return True
 
-    def default_priority(self, cursor, user, context=None):
+    def default_priority(self):
         return '1'
 
     def __init__(self):
@@ -86,24 +86,23 @@ class Request(ModelSQL, ModelView):
         self._order.insert(1, ('trigger_date', 'DESC'))
         self._order.insert(2, ('create_date', 'DESC'))
 
-    def on_change_with_number_references(self, cursor, user, vals,
-            context=None):
+    def on_change_with_number_references(self, vals):
         if vals.get('references'):
             return len(vals['references'])
         return 0
 
-    def get_number_references(self, cursor, user, ids, name, context=None):
+    def get_number_references(self, ids, name):
         res = {}
-        for request in self.browse(cursor, user, ids, context=context):
+        for request in self.browse(ids):
             if request.references:
                 res[request.id] = len(request.references)
             else:
                 res[request.id] = 0
         return res
 
-    def request_send(self, cursor, user, ids, context=None):
+    def request_send(self, ids):
         request_history_obj = self.pool.get('res.request.history')
-        for request in self.browse(cursor, user, ids, context=context):
+        for request in self.browse(ids):
             values = {
                 'request': request.id,
                 'act_from': request.act_from.id,
@@ -118,30 +117,32 @@ class Request(ModelSQL, ModelView):
                 values['name'] = values['body'][:125] + '...'
             else:
                 values['name'] = values['body'] or '/'
-            request_history_obj.create(cursor, user, values, context=context)
-        self.write(cursor, user, ids, {
+            request_history_obj.create(values)
+        self.write(ids, {
             'state': 'waiting',
             'date_send': datetime.datetime.now(),
-            }, context=context)
+            })
         return True
 
-    def request_reply(self, cursor, user, ids, context=None):
-        for request in self.browse(cursor, user, ids, context=context):
-            self.write(cursor, user, request.id, {
+    def request_reply(self, ids):
+        user = Transaction().user
+        for request in self.browse(ids):
+            self.write(request.id, {
                 'state': 'chatting',
                 'act_from': user,
                 'act_to': request.act_from.id,
                 'trigger_date': False,
                 'body': '',
-                }, context=context)
+                })
         return True
 
-    def request_close(self, cursor, user, ids, context=None):
-        self.write(cursor, user, ids, {'state': 'closed', 'active': False})
+    def request_close(self, ids):
+        self.write(ids, {'state': 'closed', 'active': False})
         return True
 
-    def request_get(self, cursor, user):
-        ids = self.search(cursor, user, [
+    def request_get(self):
+        user = Transaction().user
+        ids = self.search([
             ('act_to', '=', user),
             ['OR',
                 ('trigger_date', '<=', datetime.datetime.now()),
@@ -149,7 +150,7 @@ class Request(ModelSQL, ModelView):
             ],
             ('active', '=', True),
             ])
-        ids2 = self.search(cursor, user, [
+        ids2 = self.search([
             ('act_from', '=', user),
             ('act_to', '!=', user),
             ('state', '!=', 'draft'),
@@ -172,14 +173,14 @@ class RequestLink(ModelSQL, ModelView):
         super(RequestLink, self).__init__()
         self._order.insert(0, ('priority', 'ASC'))
 
-    def default_priority(self, cursor, user, context=None):
+    def default_priority(self):
         return 5
 
-    def models_get(self, cursor, user, context=None):
+    def models_get(self):
         model_obj = self.pool.get('ir.model')
-        model_ids = model_obj.search(cursor, user, [], context=context)
+        model_ids = model_obj.search([])
         res = []
-        for model in model_obj.browse(cursor, user, model_ids, context=context):
+        for model in model_obj.browse(model_ids):
             res.append((model.model, model.name))
         return res
 
@@ -208,20 +209,20 @@ class RequestHistory(ModelSQL, ModelView):
         super(RequestHistory, self).__init__()
         self._order.insert(0, ('date_sent', 'DESC'))
 
-    def default_name(self, cursor, user, context=None):
+    def default_name(self):
         return 'No Name'
 
-    def default_act_from(self, cursor, user, context=None):
-        return int(user)
+    def default_act_from(self):
+        return int(Transaction().user)
 
-    def default_act_to(self, cursor, user, context=None):
-        return int(user)
+    def default_act_to(self):
+        return int(Transaction().user)
 
-    def default_date_sent(self, cursor, user, context=None):
+    def default_date_sent(self):
         return datetime.datetime.now()
 
-    def write(self, cursor, user, ids, vals, context=None):
-        raise
+    def write(self, ids, vals):
+        pass
 
 RequestHistory()
 
@@ -237,11 +238,10 @@ class RequestReference(ModelSQL, ModelView):
     reference = fields.Reference('Reference', selection='links_get',
             required=True)
 
-    def links_get(self, cursor, user, context=None):
+    def links_get(self):
         request_link_obj = self.pool.get('res.request.link')
-        ids = request_link_obj.search(cursor, user, [], context=context)
-        request_links = request_link_obj.browse(cursor, user, ids,
-                context=context)
+        ids = request_link_obj.search([])
+        request_links = request_link_obj.browse(ids)
         return [(x.model, x.name) for x in request_links]
 
 RequestReference()
